@@ -35,7 +35,8 @@ my $INDEX = 0 ;
 my $TOOLTIP = 0 ;
 my $STYLE = '' ;
 my $OPTION = '' ;
-my $tooltip_prompt = '<img src="gifs/picto.gif" alt="picto">' ;
+my $tooltip_prompt = '<img src="gifs/picto.gif" alt="picto" />' ;
+$tooltip_prompt='';
 my $linkout='' ; 
 $worksheet= '';
 $SHEET = '' ;
@@ -75,8 +76,8 @@ $FILE = $_;
 
 $DIR = $DIR . '/' if ($DIR) ;
 $doc_DIR = $doc_DIR . '/' if ($doc_DIR) ; 
-my $LOAD = '\reload{<img src="gifs/doc/etoile.gif" alt="rechargez" width="20" height="20" border=0>}';
-my $FLECHE = '<img src="gifs/arrows/right3.32.gif" alt=" ---> " width="25" height="15" border=0>';
+my $LOAD = '\reload{<img src="gifs/doc/etoile.gif" alt="rechargez" style="width:20px;height:20px;" />}';
+my $FLECHE = '&#8594;';
 $linkout = "\\doc{module=$linkout}" . $FLECHE if ($linkout) ; 
 
 ##################################
@@ -114,7 +115,7 @@ my @liste_env_tabular = ('tabular') ;
 my @liste_env_spec = ('equation', 'multline', 'latexonly',
   'pmatrix','smallmatrix', 'eqnarray', 'array', 'algorithmic', 'algorithm', 'align',
   'thebibliography', 'pspicture', 'picture', 'cases', 'gather',
-  'displaymath', 'math', 'center', 'minipage', 'lstlisting', 'column', 'columns');
+  'displaymath', 'math', 'center', 'minipage', 'lstlisting', 'columns', 'column');
   
 my @liste_com_spec = ('paragraph', 'href', 'url', 'exercise', 'doc') ; #je ne m'en sers pas encore 
 
@@ -129,11 +130,11 @@ $hash_command{definition}{paragraph} = '<p class="paragraph"> #1 </p>' ;
 $hash_command{origin}{paragraph} = 'defaut' ;
 
 $hash_command{cnt_arg}{href} = 2 ;
-$hash_command{definition}{href} = '<a http:"#1" target="wims_external">#2</a>';
+$hash_command{definition}{href} = '<a href="http:#1" target="wims_external">#2</a>';
 $hash_command{origin}{href} = 'defaut' ;
 
 $hash_command{cnt_arg}{url} = 1 ;
-$hash_command{definition}{url} = '<a http:"#1" target="wims_external">#1</a>';
+$hash_command{definition}{url} = '<a href="http:#1" target="wims_external">#1</a>';
 $hash_command{origin}{url} = 'defaut' ;
 
 $hash_command{cnt_arg}{exercise} = 2 ;
@@ -260,7 +261,7 @@ out1 ('sheet', $SHEET) ;
 $ABOUT = $hash{about}{main} ; 
 out1 ('about.phtml', (($ABOUT)? $ABOUT :'') . '
 <p>
-Ce document a t cr par Latex2wims.<p>
+Ce document a t cr par Latex2wims.</p>
 
 !changeto docu/about.phtml') ;
 if (!($hash{author}{main})) {
@@ -333,9 +334,9 @@ for my $tag (keys %{$hash{text}}) {
   $T =~ s/\\($cle)\s*\{(\w*)\}/store_tag($1, $2, $tag, \%hash, \%hash_bloc)/eg;
   $hash{text}{$tag} = $T;
 }
-my @L = sort {$a cmp $b} (keys %{$hash_index{page}}) ;
-out('index', selection('<div class="index">' . makeindex (\%hash_index, 0, @L) . '</div>'
-                         ,'left-selection','index')) if ($INDEX == 1 && makeindex (\%hash_index));
+my @ListIndex = sort {$a cmp $b} (keys %{$hash_index{page}}) ;                  
+out('index', selection('<div class="index">' . makeindex (\%hash_index, 0, @ListIndex) . '</div>'
+                         ,'left-selection','index')) if ((@ListIndex) && $INDEX == 1 && makeindex (\%hash_index));
 
 #cre les blocs [entours de la table des matires]
 
@@ -357,6 +358,7 @@ for my $tag (keys %{$hash{text}}) {
   my $txt = traitement_final($hash{text}{$tag});
   my $tagupbl = $hash{upbl}{$tag};
   my $type = $hash{type}{$tag} ;
+  my $style = $hash{style}{$tag};
  #si type est non vide il est gal  embed ou fold
   my $dotoc_left = ($OPTION =~ /toc_left/ && !$type);
   my $dotoc_right = ($OPTION =~ /toc_right/ && !$type);
@@ -369,11 +371,16 @@ for my $tag (keys %{$hash{text}}) {
   my $CHEMIN_down=($dotoc_down) ? "<div id=\"down_toc\">$CHEMIN</div>" : '' ; 
   my @Chemin = split(',', $hash{chemin}{$tag});
   my $TOCg = $dotoc_left ? selection($hash{toc}{main}, 'left_selection', @Chemin) : '';
-  my $TOCd = ($dotoc_right && $tagupbl ne 'main') ? selection($hash{toc}{$tagupbl}, 'right_selection', @Chemin) : '';
+  my $TOCd = ($dotoc_right && $tag ne 'main' && (!($dotoc_left) || $tagupbl ne 'main' )) ? selection($hash{toc}{$tagupbl}, 'right_selection', @Chemin) : '';
+ 
   my $tit_index = ($hash{titb}{index})? $hash{titb}{index} : 'Index' ;
-  my $index = ($INDEX == 1) ? "\n\n\\link{index}{$tit_index}" : '';
-  my $tooltip = ($TOOLTIP == 1) ? "<script type=\"text/javascript\" src=\"scripts/js/wz_tooltip.js\"></script>" : '' ;
-  out ($tag, $tooltip . toc_HTML ($txt, clean($TOCg,\%hash), clean($TOCd,\%hash), $CHEMIN_up, $CHEMIN_down, $index) );
+  my $index = ($INDEX == 1 && (@ListIndex)) ? "<li>\\link{index}{$tit_index}</li>" : '';
+  my $tooltip = "";
+  ##$txt="<div class=\"fold\"> ".$txt ."<\/div>" if ($type=~/fold/) ;
+  my $pat= '<br\s+class="spacer"\s*/>';
+  $txt = $tooltip . toc_HTML ($txt, clean($TOCg,\%hash), clean($TOCd,\%hash), $CHEMIN_up, $CHEMIN_down, $index);
+  $txt =~ s/$pat\s*$pat/<br class="spacer" \>/g;
+  out ($tag, $txt );
 }
 if ($INDEX == 1) { out ('index.hd', hd('index',\%hash) )};
 my @style = sortuniq(split(',',$STYLE)) if ($STYLE) ;
@@ -408,10 +415,10 @@ sub analyse_texte { my ($TEXT, $ref, $Id, $niveau, $niveau_max, $Toc) = @_;
     $titre =~ s/\n/ /g;
     $titre = Numero($id) . "  $titre" if ($NUMERO);
     $toc_titre = Numero($id) . "  $toc_titre" if ($NUMERO);
-    $text .=  $link ?"\n\n\\link{$id}\n\n"
-                    :"\n\n\\fold{$id}{<span class=\"$section\">$titre</span>}\n\n";
+    $text .=  $link ?"<p>\\link{$id}</p>"
+                    :"<p>\\fold{$id}{<span class=\"$section\">$titre</span>}</p>";
     if ($link) {
-      $Toc .=  "\n\n<XXXX=$id>\\link{$id}{$toc_titre}</font><YYYY=$id>\n\n";
+      $Toc .=  "<p><XXXX=\"$id\">\\link{$id}{$toc_titre}<YYYY=\"$id\"></p>";
     }
     $text .= $extract[1];
     $ref->{titb}{$id} = $titre;
@@ -423,14 +430,17 @@ sub analyse_texte { my ($TEXT, $ref, $Id, $niveau, $niveau_max, $Toc) = @_;
     $ref->{prev}{$id} = $idold;
     $ref->{next}{$idold} = $id;
    #modifier avec selection
-    my $tp = '' ; 
+    my $tp = '' ;
     if ($TOOLTIP==1) {
-    if (!$ref->{toctip}{$Id}) {$ref->{toctip}{$Id}=' ' ; } else {
-      $ref->{toctip}{$Id} .= ($ref->{tittoc}{$id}) ?  '<br>': '' ;}
-    $ref->{toctip}{$Id} .= $ref->{tittoc}{$id} ;
+    if (!$ref->{toctip}{$Id}) {$ref->{toctip}{$Id}=($ref->{tittoc}{$id}) ?  
+      "<li>\\link{$id}{$ref->{tittoc}{$id}}</li>": '' ; } 
+    else {
+      $ref->{toctip}{$Id} .= ($ref->{tittoc}{$id}) ?  "<li>\\link{$id}{$ref->{tittoc}{$id}}</li>": '' ;
+    }
+    #$ref->{toctip}{$Id} .= $ref->{tittoc}{$id} ;
     $tp = "ZZZZZ$id" ; }
-    $ref->{toc}{$Id} .= "\n<XXXX=$id>\\link{$id}{$ref->{tittoc}{$id}
-    }$tp <YYYY=$id>\n";
+    $ref->{toc}{$Id} .= "\n<XXXX=\"$id\">\\link{$id}{$ref->{tittoc}{$id}
+    }$tp <YYYY=\"$id\">";
   }
  #maintenant, ce qui reste dans $text est exactement ce qu'on doit mettre dans le hash->{text}{$Id}
   $ref->{text}{$Id} = $text;
@@ -446,7 +456,7 @@ sub store_tag { my ($cle, $label, $tag, $ref, $ref_bloc) = @_;
 
 sub store_label { my ($label, $Id, $ref) = @_;
    $ref->{fichier}{$label} = $Id; 
-   "<a name=\"$label\"></a>";
+   "<a id=\"$label\"></a>";
 }
 
 sub dbg { print STDERR "$_[0]\n" if ($verbose); }
@@ -455,7 +465,7 @@ sub store_index { my ($label, $Id, $ref_index) = @_;
    dbg("... index: \"$label\"");
    my $L = $ref_index->{page}{$label};
    $ref_index->{page}{$label} =  !$L ? $Id : "$L,$Id";
-   "<a name=\"$label\"></a>";
+   "<a id=\"$label\"></a>";
 }
 
 sub class_index { my ($index,$level) = @_ ; 
@@ -465,7 +475,7 @@ sub class_index { my ($index,$level) = @_ ;
  #!(keys %{$ref_index->{page}}
  #sort keys %{$ref_index->{page}} ; 
 
-sub makeindex { my ($ref_index, $level, @L ) = @_; 
+sub makeindex { my ($ref_index, $level, @L ) = @_;
    return '' if (!$#L) ;
    my $dejavu = '' ;
    my $TEXT = "\n<ul class=\"index\">";
@@ -491,7 +501,7 @@ sub TraiteText {my ($TEXT, $ref, $ref_env, $Id) = @_;
   $TEXT =~ s/\s*$//; # strip trailing whitespace
  #0 ul et li sans rien
  #1 avec style
- $TEXT =~ s/\\(begin|end)\s*{wimsonly}/\n/g;
+ $TEXT =~ s/\\(begin|end)\s*{wimsonly}//g;
  for my $rubrique (keys %{$ref_env->{list}}) {
      $TEXT = traite_list ($TEXT, $ref, $ref_env, $Id, $rubrique,1);
  }
@@ -533,6 +543,10 @@ for my $rubrique (@liste_env_tabular) {
      warn " ATTENTION : environnement non rpertori : $1" if $1 ne 'matrix';
   }
   $TEXT =~ s,<li>\n+</li>,<li></li>,g;
+  $TEXT =~ s,</div>\s+</div>,</div></div>,g;
+  $TEXT =~ s,</div>\s+<,</div>\n<,g;
+  $TEXT =~ s,<div ([^>]+)>\s+<,<div $1><,g;
+  $TEXT =~ s/\n{2,5}/<br class=\"spacer\" \/>/g;
   $TEXT;
 }
 
@@ -618,7 +632,7 @@ sub traite_environ {my ($TEXT, $ref, $ref_env, $Id, $environ, $cnt) = @_;
       $ref->{upbl}{$newtag} = $Id;
       $milieu = "\n\\$type\{$newtag\}\{"
         . encadr_defaut("<$environ>$titre<\/$environ>", $environ, $ref_env,'titre')
-        . "\}\n\n" ;
+        . "\}\n" ;
     } else {  my $milieu1 = $milieu ; 
       $milieu = encadrement("<$environ>$milieu<\/$environ>", $environ, $ref_env, 'full');
     }
@@ -651,9 +665,9 @@ sub complete {my ($tag, $ref) = @_;
   if ($INDEX == 1 && !($ref->{titb}{index})) { $ref->{titb}{index} = 'Index' ;}
 }
 
-#option full  <h2 class="defn">Dfinition [titre perso]</h2> <div class= "definition">  </div> si cela existe
+#option full  <h2 class=" l2w_content defn">Dfinition [titre perso]</h2> <div class= " l2w_content definition">  </div> si cela existe
 #option bloc  <div class= "definition"> </div>  si cela existe (intrieur d'un fold ou d'un link)
-#option titre  <h2 class="defn">Dfinition </h2>  si cela existe (titre d'un fold)
+#option titre  <h2 class="l2w_content defn">Dfinition </h2>  si cela existe (titre d'un fold)
 sub encadr_defaut { my ($TEXT, $rubrique, $ref_env, $option) = @_;
   my $a = $ref_env->{titre}{$rubrique};
   my $b = $ref_env->{style}{$rubrique};
@@ -662,21 +676,21 @@ sub encadr_defaut { my ($TEXT, $rubrique, $ref_env, $option) = @_;
     $ref_env->{style}{$rubrique} = $b;
     dbg("... environnement $rubrique sans style css, par defaut $rubrique")
   };
-  my $div_d = "<div class=\"$b\">";
+  my $div_d = "<div class=\"l2w_content $b\">";
   my $div_f = '</div>';
   if ( $option eq 'titre') { 
-    $TEXT =~ s/<$rubrique>/<span class=\"$b\">/g;
-    $TEXT =~ s/<\/$rubrique>/<\/span>\n\n/g;
+    $TEXT =~ s/<$rubrique>/<span class=\"l2w_content $b\">/g;
+    $TEXT =~ s/<\/$rubrique>/<\/span>\n/g;
   } elsif (!$a || $option eq 'bloc') {
     $TEXT =~ s/<$rubrique>\s*(\[[^\]]+\])?/$div_d/g;
-    $TEXT =~ s/<\/$rubrique>/$div_f\n\n/g;
+    $TEXT =~ s/<\/$rubrique>/$div_f/g;
   } elsif ($option eq 'full') {
-    $TEXT =~ s/<$rubrique>\s*(\[[^\]]+\])/<h2 class=\"$b\">$a $1<\/h2>$div_d/g;
-    $TEXT =~ s/<$rubrique>/<h2 class=\"$b\">$a<\/h2>$div_d/g;
-    $TEXT =~ s/<\/$rubrique>/$div_f\n\n/g;
+    $TEXT =~ s/<$rubrique>\s*(\[[^\]]+\])/<h2 class=\"l2w_content $b\">$a $1<\/h2>$div_d/g;
+    $TEXT =~ s/<$rubrique>/<h2 class=\"l2w_content $b\">$a<\/h2>$div_d/g;
+    $TEXT =~ s/<\/$rubrique>/$div_f/g;
   } else  { 
     $TEXT =~ s/<$rubrique>/<span class=\"$b\">/g;
-    $TEXT =~ s/<\/$rubrique>/<\/span>\n\n/g;
+    $TEXT =~ s/<\/$rubrique>/<\/span>\n/g;
   }
   $TEXT;
 }
@@ -721,8 +735,8 @@ sub tabular { my ( $b, $style ) = @_;
 sub includegraphics{ my ( $b, $opt ) = @_;
    $b=~ s/.(pdf|tiff|eps|svg)/.png/ ; 
    $opt =~ s/.*(width|height)\s*=\s*([0-9]*\.?[0-9]*\s*)(\\(line|text)width)/linewidth("$2$3",$1)/eg;
-   $opt =~ s/.*(width|height)\s*=\s*([0-9]*\.?[0-9]*\s*)(cm|px)/$1=\"$2$3\"/;
-  "<img src=\"\\filedir\/$b\" $opt alt=\"\">";
+   $opt =~ s/.*(width|height)\s*=\s*([0-9]*\.?[0-9]*\s*)(cm|px)/ style=\"$1:$2$3;\"/;
+  "<img src=\"\\filedir\/$b\" $opt alt=\"\" />";
 }
  
 sub minipage { my ( $b ) = @_; 
@@ -747,12 +761,15 @@ sub columns { my ( $b ) = @_;
 
 sub column { my ( $b ) = @_; 
  my @v = extract_bracketed ($b, '[]') ;
- my $option = $v[0] ;  
- $option=~ s/\[\s*b\s*\]/bottom/ ;  
- $option=~ s/\[\s*t\s*\]/top/ ;
- $option=~ s/\[\s*c\s*\]/middle/ ; 
- $option=~s/\[\s*\]/middle/;
- if (!$option) { $option='middle'} ;
+ my $option = '';
+ $option= $v[0] ; 
+ if($option) {
+  $option=~ s/\[\s*b\s*\]/bottom/ ;  
+  $option=~ s/\[\s*t\s*\]/top/ ;
+  $option=~ s/\[\s*c\s*\]/middle/ ; 
+  $option=~s/\[\s*\]/middle/; 
+  }
+ else{ $option='top'} ;
  @v = extract_bracketed ($v[1], '{}') ;
  my $width = $v[0] ;
  $width =~ s/\{(.*)\}/$1/;
@@ -774,8 +791,8 @@ sub verbatim { my ($b,$id ) = @_ ;
 }
 
 sub multline { my ( $b) = @_;
-  $b =~ s/\\\\\s*=/\\)<br>\\(== /g;
-  $b =~ s|\\\\|\\)<br>\\(|g;
+  $b =~ s/\\\\\s*=/\\)<br\/>\\(== /g;
+  $b =~ s|\\\\|\\)<br\/>\\(|g;
   "<div class=\"math\">\\(" . $b . "\\)</div>\n";
 }
 
@@ -791,7 +808,7 @@ sub align1 { my ( $b) = @_;
   '<div class="math">' . $b . '</div>' ;
 }
 sub align { my ( $b) = @_;
-  $b =  '<table border=0 align="center" class="tableau"><tr><td>\\(' . $b . '\\\\</table>';
+  $b =  '<table class="wimscenter wimsnoborder tableau" style="width:100%"><tr><td>\\(' . $b . '\\\\</table>';
   if ($b =~ s/\\label{([^\}])}//) { $b = "\\label{$1}" . $b };
   $b =~ s|\&|\\)&nbsp;</td><td>&nbsp;\\(|g;
   $b =~ s|\\\\\s*</table>|\\)</td></tr></table>|g;
@@ -828,7 +845,7 @@ sub gather { my ($b) = @_;
   $b;
 }
 
-sub displaymath {"<div class=\"math\">\\( " . $_[0]. "\\)</div>"; }
+sub displaymath {"<div class=\"math\">\\(\\displaystyle{ " . $_[0]. "}\\)</div>"; }
 sub math {" \\( " . $_[0]. "\\) "; }
 
 
@@ -1120,7 +1137,7 @@ sub traitement_final { my ($TEXT) = @_;
 sub traitemath {my ($txt) = @_;
   my $test = 0;
   while ($txt =~ /\$\$/) {
-    $txt = $` . ($test == 0 ? '<div class="math">\\(' : '\\)</div>') . $';
+    $txt = $` . ($test == 0 ? '<div class="math">\\(\\displaystyle{' : '}\\)</div>') . $';
     $test = 1-$test;
   }
   $txt;
@@ -1189,6 +1206,7 @@ sub traitement_initial { my ($TEXT) = @_;
   $TEXT =~ s/{\s*\\\^\s*u\s*}//g;
   $TEXT =~ s/{\s*\\`\s*u\s*}//g;
   $TEXT =~ s/{\s*\\c \s*c\s*}//g;
+  $TEXT =~ s/\\maketitle//g;
   $TEXT =~ s/{\\textquotesingle}/'/g;
   $TEXT =~ s/\\textquotesingle/'/g;
   $TEXT =~ s/\\guillemotleft/<</g;
@@ -1202,6 +1220,8 @@ sub traitement_initial { my ($TEXT) = @_;
   $TEXT =~ s/\\onslide\+<[0-9]*\-[0-9]*>//g;
   $TEXT =~ s/\\onslide<[0-9]*\-[0-9]*->//g;
   $TEXT =~ s/\\onslide<[0-9]*\-[0-9]*>//g;
+  $TEXT =~ s/\[<\+->\]//g;
+ 
 # MODIF YVES NOEL 19/09/2011 (fin)
   $TEXT =~ s/{}//g;
   $TEXT =~ s/\\selectlanguage{french}\\sffamily//g;
@@ -1231,6 +1251,7 @@ sub traitement_initial { my ($TEXT) = @_;
 sub traite_beamer {  my ($TEXT) = @_;
    $TEXT =~ s/\\uncover\s*(<([^>]+)>)?\s*{(.*)}/\\fold{.}{-->}{$3}/g ; 
    $TEXT =~ s/\s*\\frametitle{([^}]+)}/store_frametitle($1)/ge;
+   $TEXT =~ s/\\pause//g;
    $TEXT ;
 }
 
@@ -1283,7 +1304,7 @@ sub def { my ($ref, @style) = @_;
   my $aut = $ref->{author}{main};
   my $mail= $ref->{email}{main};
   my $datm= $ref->{datm}{main};
-  my $header = '' ;
+  my $header = '<link rel="stylesheet" href="html/themes/_css/l2w.css" type="text/css" />'  ;
   my $header_tmp ;
   for my $file (@style){
     if (!open(IN, $DIR . $file)) { die "le fichier $DIR$file n'existe pas";}
@@ -1292,6 +1313,12 @@ sub def { my ($ref, @style) = @_;
     $header .= "\t $header_tmp" ;
   }
   close IN;
+  $header .= "\t<script type=\"text/javascript\">"
+   . "jQuery.noConflict();"
+   . "jQuery(function() {jQuery( \"#left_toc\" ).menu();});" 
+   . "jQuery(function() {jQuery( \"#right_toc\" ).menu();});"
+   . "</script>" if ($TOOLTIP==1);
+ 
 "copyright=gnu
 docopen=yes
 dlang=fr
@@ -1325,17 +1352,19 @@ sub toc_HTML {my ($text, $toc_g, $toc_d, $CHEMIN_up, $CHEMIN_down, $index) = @_
    $s= "l"  if($toc_g) ; $s .= "r" if($toc_d) ;
   if (($toc_g) || ($toc_d)) {
     $CHEMIN_up . '<div class="doc_latex2wims' . $s . '">'
-   . (($toc_g) ? '<div class="left_toc">'. $toc_g 
-   . $index . '</div>' : '')
+   . (($toc_g) ? '<ul id="left_toc" class="left_toc">'. $toc_g 
+   . $index . '</ul>' : '')
    . '<div class="wimsdoc">'
    . $text
    . '</div>'
-   . (($toc_d) ? '<div class="right_toc">'
+   . (($toc_d) ? '<ul id="right_toc" class="right_toc">'
    . $toc_d
-   . '<center>'
+   . '<div class="wimscenter">'
    . $LOAD
-   . '</center></div>' : '')
-   . $CHEMIN_down ;
+   . '</div></div>' : '')
+   . $CHEMIN_down . 
+   '</div>';
+
    }
 
    else {$CHEMIN_up . $text . $CHEMIN_down };
@@ -1347,8 +1376,14 @@ sub store_algo { my ($txt, $acc, $cmd, $comment, $indent) = @_ ;
   $txt .= " " . $acc ;
   $txt .= $hash_algo{titre}{$hash_algo{suite}{$cmd}} if  ($hash_algo{suite}{$cmd}) ;
   $indent = $indent + $hash_algo{avant}{$cmd} ;
-  $txt = "\n" . indent($indent) .  $hash_algo{titre}{$cmd} . $txt  if ( !($cmd =~ /END/) || $algo_noend == 0);
-  $txt .=  indent(3) . "{<i>$comment</i>}" if ($comment) ;
+  if($hash_algo{titre}{$cmd}) {
+   $txt = "\n" . indent($indent) .  $hash_algo{titre}{$cmd} . $txt  if ( !($cmd =~ /END/) || $algo_noend == 0);
+  }
+  else
+  {
+   $txt = "\n" . indent($indent) . $txt  if ( !($cmd =~ /END/) || $algo_noend == 0);
+  }
+  $txt .=  indent('3') . "{<i>$comment</i>}" if ($comment) ;
   $txt .= "\n" ;
   $txt =~ s/\n+/\n/ ;
   $indent += $hash_algo{apres}{$cmd} ;
@@ -1385,10 +1420,11 @@ sub algorithmic { my ($Text) = @_;
     #des commentaires ?
     if ($ligne =~ /^\s*\\COMMENT/) { $ligne = "<i>$ligne</i>\n" };
     $text .= "\n" . $ligne;
-    $text =~ s/\n{2,}/\n/g ;
-    $text =~ s/\n+/<br>/g ;
-    $text =~ s/(<br>)+/<br>/g ;
+    $text =~ s/\n{2,}/\n/g;
+    $text =~ s/(<br\s*\/>)+/<br \/>/g;
+    $text =~ s/(<br>)+/<br \/>/g;
   }
+  $text =~ s/\n/<br \/>/g;
   $text ;
 }
 
@@ -1409,16 +1445,16 @@ sub Numero { my ($id) = @_;
 sub selection { my ($text, $couleur, @tag) = @_ ;
   return '' if !defined($text);
   for my $ta (@tag) {
-    $text =~ s/XXXX=$ta>/div class="$couleur">/g;
-    $text =~ s/YYYY=$ta>/\/div>/g;
+    $text =~ s/XXXX="$ta">/li class="$couleur">/g;
+    $text =~ s/YYYY="$ta">/\/li>/g;
   };
   $text;
 }
 
 sub clean { my ($text, $ref) = @_;
   return '' if !defined($text);
-   $text =~ s/<XXXX=\w*>//g;
-   $text =~ s/<YYYY=\w*>//g;
+   $text =~ s/<XXXX="\w*">/<li class="no_selected">/g;
+   $text =~ s/<YYYY="\w*">/<\/li>/g;
    $text =~ s/ZZZZZ(\w+)/store_tip($1,$ref)/ge;
    $text;
 }
@@ -1426,9 +1462,9 @@ sub clean { my ($text, $ref) = @_;
 sub store_tip { my ($tag,$ref)=@_ ; 
   my $tip = $ref->{toctip}{$tag} ;
   my $title=$ref->{tittoc}{$tag} ;
-  $tip =~ s/'/\\\\'/g if ($tip) ; 
-   $title =~ s/'/\\\\'/g if ($title) ; 
-  $ref->{toctip}{$tag} ?  "<a onmouseover=\"Tip('$tip',TITLE,'$title',TITLEBGCOLOR,'',WIDTH,'200px')\" onmouseout=\"UnTip()\">$tooltip_prompt<\/a>" : '' ; 
+  #$tip =~ s/'/\\\\'/g if ($tip) ; 
+  $title =~ s/'/\\\\'/g if ($title) ; 
+  $ref->{toctip}{$tag} ? "<ul>$tip</ul>" : '' ; 
 }
 
 sub chemin { my ($tag, $ref) = @_;
@@ -1439,8 +1475,8 @@ sub chemin { my ($tag, $ref) = @_;
   while ($tagsup !~ /^main\b/) {
     $niv++;
     $tagsup = $ref->{upbl}{$tagsup};
-    $ch  = "$tagsup,$ch";
-    $txt = "\\link{$tagsup}{$ref->{tittoc}{$tagsup}} $FLECHE $txt" ; #if ($tagsup !~ /^main\b/);
+    $ch  = "$tagsup,$ch"; if (!$ref->{tittoc}{$tagsup}) { $ref->{tittoc}{$tagsup}=$tagsup};
+    $txt = "\\link{$tagsup}{$ref->{tittoc}{$tagsup}} $FLECHE $txt" if ($tagsup) ; #if ($tagsup !~ /^main\b/);
   }
   $ref->{chemin}{$tag} = $ch;
   $ref->{niveau}{$tag} = $niv;
