@@ -168,6 +168,9 @@ char temp_log[MAX_FNAME+1];	/* temp log file name */
 	/* 0: low; 1: high; 2: MathML */
 int mathalign_base=0;		/* Not use <sup> for middle alignment */
 char *disable_zoom="no"; 	/* yes/no:  default zooming allowed (if enabled via "useropts")  */
+int spec_font=0; /* choose of some fonts*/
+ /* special font can be configured in log/wims.conf with variable special_font*/
+char *special_font="letter-spacing:0.3em;line-height:2.7em;word-spacing:0.8em;";
 int backup_hour=-1;		/* Hour for daily backup; -1 means no backup. */
 int site_accounting=0;		/* whether accounting should be activated */
 int examlog_limit=7;		/* number of logged exam sessions for each student */
@@ -175,7 +178,7 @@ int examlog_limit=7;		/* number of logged exam sessions for each student */
   /* Automatic module update */
 char *mu_auto="none";
 char *mu_cat="all";
-char *mu_delay="20";
+char *mu_delay="3";
 char *mu_site="http://wims.unice.fr/download/modules";
 char *mu_zone="all";
 char *mu_download_site="unice,wimsedu";
@@ -591,6 +594,16 @@ char *modindex[]={
       "domain",
       "help",
       "keywords",
+      "keywords_ca",
+      "keywords_cn",
+      "keywords_de",
+      "keywords_en",
+      "keywords_es",
+      "keywords_fr",
+      "keywords_it",
+      "keywords_nl",
+      "keywords_si",
+      "keywords_tw",
       "language",
       "level",
       "maintainer",
@@ -755,8 +768,8 @@ void define_html_header(void)
 {
   char *expir, *sp, *cp, *ladirection, *mp;
     char buf[MAX_LINELEN+1],ebuf[128];
-    char *nocache="<meta http-equiv=\"Pragma\" content=\"no-cache\">\n\
-<meta http-equiv=\"Cache-Control\" content=\"no-cache\">\n";
+    char *nocache="<meta http-equiv=\"Pragma\" content=\"no-cache\" />\n\
+<meta http-equiv=\"Cache-Control\" content=\"no-cache\" />\n";
     int noc;
     time_t t;
 
@@ -787,7 +800,7 @@ void define_html_header(void)
 	}
 	snprintf(ebuf,sizeof(ebuf),"%s",expir); strip_trailing_spaces(ebuf);
 	snprintf(buf,sizeof(buf),
-		 "<meta http-equiv=\"expires\" content=\"%s\">\n%s",ebuf,nocache);
+		 "<meta http-equiv=\"expires\" content=\"%s\" />\n%s",ebuf,nocache);
 	setvar("wims_expire",buf);
     }
     css: setvar("wims_CSS","");
@@ -826,8 +839,9 @@ void define_html_header(void)
 %s\n\
 --></style>",tmplbuf); }
 		  else {
-		  snprintf(buf,sizeof(buf),"<link href=\"%s\" rel=\"stylesheet\" type=\"text/css\">\n\
-		  <link href=\"gifs/themes/%s/icon.css\" rel=\"stylesheet\" type=\"text/css\">",nbuf,ti);
+		  snprintf(buf,sizeof(buf),"<link href=\"%s\" rel=\"stylesheet\" type=\"text/css\" />\n\
+<link href=\"html/themes/$wims_theme/theme.css\" rel=\"stylesheet\" type=\"text/css\" />\n\
+<link href=\"gifs/themes/%s/icon.css\" rel=\"stylesheet\" type=\"text/css\" />",nbuf,ti);
 		 }
 		setvar("wims_CSS",buf);
 	    }
